@@ -3,4 +3,4 @@
 import psycop_feature_generation.loaders.raw.load_diagnoses as d
 
 if __name__ == "__main__":
-    df = d.gerd(n_rows=200)
+    df = d.gerd(n_rows=1_000)
