@@ -3,7 +3,6 @@
 from ...data_checks.raw.check_predictor_lists import (  # noqa
     check_feature_combinations_return_correct_dfs,
 )
-from .load_admissions import *  # noqa
 from .load_coercion import *  # noqa
 from .load_demographic import *  # noqa
 from .load_diagnoses import *  # noqa
@@ -14,4 +13,3 @@ from .load_structured_sfi import *  # noqa
 from .load_t2d_outcomes import *  # noqa
 from .load_visits import *  # noqa
 from .sql_load import *  # noqa
-from .t2d_loaders import *  # noqa
