@@ -1,18 +1,21 @@
 """Example of."""
 
+import logging
 from typing import Optional, Union
 
 import pandas as pd
 
 from psycop_feature_generation.loaders.raw.sql_load import sql_load
 
+log = logging.getLogger(__name__)
+
 
 def str_to_sql_match_logic(
     code_to_match: str,
     code_sql_col_name: str,
     load_diagnoses: bool,
     match_with_wildcard: bool,
-):
+) -> str:
     """Generate SQL match logic from a single string.
 
     Args:
@@ -78,6 +81,11 @@ def load_from_codes(
     match_with_wildcard: bool = True,
     n_rows: Optional[int] = None,
     exclude_codes: Optional[list[str]] = None,
+    administration_route: Optional[str] = None,
+    administration_method: Optional[str] = None,
+    shak_location_col: Optional[str] = None,
+    shak_code: Optional[int] = None,
+    shak_sql_operator: Optional[str] = None,
 ) -> pd.DataFrame:
     """Load the visits that have diagnoses that match icd_code or atc code from
     the beginning of their adiagnosekode or atc code string. Aggregates all
@@ -102,6 +110,11 @@ def load_from_codes(
             Defaults to true.
         n_rows: Number of rows to return. Defaults to None.
         exclude_codes (list[str], optional): Drop rows if their code is in this list. Defaults to None.
+        administration_route (str, optional): Whether to subset by a specific administration route, e.g. 'OR', 'IM' or 'IV'. Defaults to None.
+        administration_method (str, optional): Whether to subset by method of administration, e.g. 'PN' or 'Fast'. Defaults to None.
+        shak_location_col (str, optional): Name of column containing shak code. Defaults to None. Combine with shak_code and shak_sql_operator.
+        shak_code (int, optional): Shak code indicating where to keep/not keep visits from (e.g. 6600). Defaults to None.
+        shak_sql_operator (str, optional): Operator indicating how to filter shak_code, e.g. "!= 6600" or "= 6600". Defaults to None.
 
     Returns:
         pd.DataFrame: A pandas dataframe with dw_ek_borger, timestamp and
@@ -127,10 +140,116 @@ def load_from_codes(
         raise ValueError("codes_to_match must be either a list or a string.")
 
     sql = (
-        f"SELECT dw_ek_borger, {source_timestamp_col_name}, {code_col_name}"
-        + f" FROM [fct].{fct} WHERE {source_timestamp_col_name} IS NOT NULL AND ({match_col_sql_str})"
+        f"SELECT dw_ek_borger, {source_timestamp_col_name}, {code_col_name} "
+        + f"FROM [fct].{fct} WHERE {source_timestamp_col_name} IS NOT NULL AND ({match_col_sql_str})"
     )
 
+    if shak_code is not None:
+        sql += f" AND left({shak_location_col}, {len(str(shak_code))}) {shak_sql_operator} {str(shak_code)}"
+
+    if administration_method:
+        allowed_administration_methods = (
+            "Fast",
+            "PN",
+            "Engangs",
+            "Alternerende",
+            "Kontinuerlig",
+            "Skema2",
+            "Skema",
+            "Tidspunkter",
+        )
+        if administration_method not in allowed_administration_methods:
+            log.warning(
+                "Value for administration method does not exist, returning 0 rows. "
+                + f"Allowed values are {allowed_administration_methods}.",
+            )
+        sql += f" AND type_kodetekst = '{administration_method}'"
+
+    if administration_route:
+        allowed_administration_routes = (
+            "OR",
+            "IV",
+            "IH",
+            "IM",
+            "SC",
+            "KU",
+            "IA",
+            "IR",
+            "PR",
+            "IN",
+            "OK",
+            "TD",
+            "PO",
+            "SL",
+            "BS",
+            "DE",
+            "ED",
+            "CO",
+            "VA",
+            "LO",
+            "PE",
+            "AU",
+            "RE",
+            "IE",
+            "IU",
+            "UR",
+            "GA",
+            "OG",
+            "OS",
+            "IC",
+            "OM",
+            "ET",
+            "HE",
+            "IB",
+            "BR",
+            "KO",
+            "VI",
+            "EC",
+            "IL",
+            "IP",
+            "IT",
+            "MP",
+            "CA",
+            "IO",
+            "IS",
+            "CE",
+            "ID",
+            "ES",
+            "SM",
+            "TR",
+            "PA",
+            "PT",
+            "TO",
+            "PD",
+            "ON",
+            "BU",
+            "GI",
+            "OF",
+            "AM",
+            "CB",
+            "EL",
+            "PV",
+            "LY",
+            "XA",
+            "IF",
+            "AL",
+            "DI",
+            "PN",
+            "PC",
+            "BD",
+            "IG",
+            "HS",
+            "TU",
+            "PJ",
+            "LF",
+        )
+        if administration_route not in allowed_administration_routes:
+            log.warning(
+                "Value for administration route does not exist, returning 0 rows. "
+                + f"Allowed values are {allowed_administration_routes}.",
+            )
+        sql += f" AND admvej_kodetekst = '{administration_route}'"
+
     df = sql_load(sql, database="USR_PS_FORSK", chunksize=None, n_rows=n_rows)
 
     if exclude_codes:
