@@ -39,6 +39,9 @@ def str_to_df(
     convert_timestamp_to_datetime: bool = True,
     convert_np_nan_to_nan: bool = True,
     convert_str_to_float: bool = False,
+    add_pred_time_uuid: bool = False,
+    entity_id_colname: str = "entity_id",
+    timestamp_col_name: str = "timestamp",
 ) -> DataFrame:
     """Convert a string representation of a dataframe to a dataframe.
 
@@ -47,10 +50,15 @@ def str_to_df(
         convert_timestamp_to_datetime (bool): Whether to convert the timestamp column to datetime. Defaults to True.
         convert_np_nan_to_nan (bool): Whether to convert np.nan to np.nan. Defaults to True.
         convert_str_to_float (bool): Whether to convert strings to floats. Defaults to False.
+        add_pred_time_uuid (bool): Whether to infer a pred_time_uuid column from entity_id and timestamp columns. Defaults to False.
+        entity_id_colname (str): The name of the entity_id column. Defaults to "entity_id".
+        timestamp_col_name (str): The name of the timestamp column. Defaults to "timestamp".
 
     Returns:
         DataFrame: A dataframe.
     """
+    # Drop comments for each line if any exist inside the str
+    string = string[: string.rfind("#")]
 
     df = pd.read_table(StringIO(string), sep=",", index_col=False)
 
@@ -65,6 +73,11 @@ def str_to_df(
         # Convert all str to float
         df = df.apply(pd.to_numeric, axis=0, errors="coerce")
 
+    if add_pred_time_uuid:
+        df["pred_time_uuid"] = (
+            df[entity_id_colname].astype(str) + "_" + df[timestamp_col_name].astype(str)
+        )
+
     # Drop "Unnamed" cols
     return df.loc[:, ~df.columns.str.contains("^Unnamed")]
 
